@@ -3,92 +3,122 @@ package Acme::AjiFry;
 use warnings;
 use strict;
 use utf8;
-use feature qw(switch);
-
 use Encode;
 use List::Util;
-use base 'Class::Accessor::Fast';
 
-use version; our $VERSION = '0.08';
+our $VERSION = '0.09';
 
-our %cols;
-our %rows;
-our @dullness;
-our @p_sound;
-our @double_consonant;
+use constant COLS => {
+    a => [
+        'あ', 'か', 'さ', 'た', 'な', 'は', 'ま', 'や', 'ら', 'わ',
+        'が', 'ざ', 'だ', 'ば', 'ぱ', 'ぁ', 'ゃ', 'ゎ'
+    ],
+    i => [
+        'い', 'き', 'し', 'ち', 'に', 'ひ', 'み', 'り',
+        'ぎ', 'じ', 'ぢ', 'び', 'ぴ', 'ぃ'
+    ],
+    u => [
+        'う', 'く', 'す', 'つ', 'ぬ', 'ふ', 'む', 'ゆ', 'る', 'ぐ',
+        'ず', 'づ', 'ぶ', 'ぷ', 'ぅ', 'っ', 'ゅ'
+    ],
+    e => [
+        'え', 'け', 'せ', 'て', 'ね', 'へ', 'め', 'れ',
+        'げ', 'ぜ', 'で', 'べ', 'ぺ', 'ぇ',
+    ],
+    o => [
+        'お', 'こ', 'そ', 'と', 'の', 'ほ', 'も', 'よ', 'ろ', 'を',
+        'ご', 'ぞ', 'ど', 'ぼ', 'ぽ', 'ぉ', 'ょ'
+    ],
+    n => ['ん'],
+};
+use constant ROWS => {
+    a =>
+      [ 'あ', 'い', 'う', 'え', 'お', 'ぁ', 'ぃ', 'ぅ', 'ぇ', 'ぉ' ],
+    k =>
+      [ 'か', 'き', 'く', 'け', 'こ', 'が', 'ぎ', 'ぐ', 'げ', 'ご' ],
+    s =>
+      [ 'さ', 'し', 'す', 'せ', 'そ', 'ざ', 'じ', 'ず', 'ぜ', 'ぞ' ],
+    t => [
+        'た', 'ち', 'つ', 'て', 'と', 'だ',
+        'ぢ', 'づ', 'で', 'ど', 'っ'
+    ],
+    n => [ 'な', 'に', 'ぬ', 'ね', 'の' ],
+    h => [
+        'は', 'ひ', 'ふ', 'へ', 'ほ', 'ば', 'び', 'ぶ',
+        'べ', 'ぼ', 'ぱ', 'ぴ', 'ぷ', 'ぺ', 'ぽ'
+    ],
+    m => [ 'ま', 'み', 'む', 'め', 'も' ],
+    y => [ 'や', 'ゆ', 'よ', 'ゃ', 'ゅ', 'ょ' ],
+    r => [ 'ら', 'り', 'る', 'れ', 'ろ' ],
+    w => [ 'わ', 'を', 'ゎ' ],
+};
+use constant DULLNESS => [
+    'が', 'ぎ', 'ぐ', 'げ', 'ご', 'ざ', 'じ', 'ず', 'ぜ', 'ぞ',
+    'だ', 'ぢ', 'づ', 'で', 'ど', 'ば', 'び', 'ぶ', 'べ', 'ぼ'
+];
+use constant P_SOUND => [ 'ぱ', 'ぴ', 'ぷ', 'ぺ', 'ぽ' ];
+use constant DOUBLE_CONSONANT =>
+  [ 'ぁ', 'ぃ', 'ぅ', 'ぇ', 'ぉ', 'っ', 'ゃ', 'ゅ', 'ょ', 'ゎ' ];
 
 sub new {
     my $class = shift;
+    return $class;
+}
 
-    $cols{a} = [
-        'あ', 'か', 'さ', 'た', 'な', 'は', 'ま', 'や', 'ら', 'わ',
-        'が', 'ざ', 'だ', 'ば', 'ぱ', 'ぁ', 'ゃ', 'ゎ'
-    ];
-    $cols{i} = [
-        'い', 'き', 'し', 'ち', 'に', 'ひ', 'み', 'り',
-        'ぎ', 'じ', 'ぢ', 'び', 'ぴ', 'ぃ'
-    ];
-    $cols{u} = [
-        'う', 'く', 'す', 'つ', 'ぬ', 'ふ', 'む', 'ゆ', 'る', 'ぐ',
-        'ず', 'づ', 'ぶ', 'ぷ', 'ぅ', 'っ', 'ゅ'
-    ];
-    $cols{e} = [
-        'え', 'け', 'せ', 'て', 'ね', 'へ', 'め', 'れ',
-        'げ', 'ぜ', 'で', 'べ', 'ぺ', 'ぇ',
-    ];
-    $cols{o} = [
-        'お', 'こ', 'そ', 'と', 'の', 'ほ', 'も', 'よ', 'ろ', 'を',
-        'ご', 'ぞ', 'ど', 'ぼ', 'ぽ', 'ぉ', 'ょ'
-    ];
-    $cols{n} = ['ん'];
+sub to_AjiFry {
+    my ( $self, $raw_string ) = @_;
 
-    $rows{a} =
-      [ 'あ', 'い', 'う', 'え', 'お', 'ぁ', 'ぃ', 'ぅ', 'ぇ', 'ぉ' ];
-    $rows{k} =
-      [ 'か', 'き', 'く', 'け', 'こ', 'が', 'ぎ', 'ぐ', 'げ', 'ご' ];
-    $rows{s} =
-      [ 'さ', 'し', 'す', 'せ', 'そ', 'ざ', 'じ', 'ず', 'ぜ', 'ぞ' ];
-    $rows{t} = [
-        'た', 'ち', 'つ', 'て', 'と', 'だ',
-        'ぢ', 'づ', 'で', 'ど', 'っ'
-    ];
-    $rows{n} = [ 'な', 'に', 'ぬ', 'ね', 'の' ];
-    $rows{h} = [
-        'は', 'ひ', 'ふ', 'へ', 'ほ', 'ば', 'び', 'ぶ',
-        'べ', 'ぼ', 'ぱ', 'ぴ', 'ぷ', 'ぺ', 'ぽ'
-    ];
-    $rows{m} = [ 'ま', 'み', 'む', 'め', 'も' ];
-    $rows{y} = [ 'や', 'ゆ', 'よ', 'ゃ', 'ゅ', 'ょ' ];
-    $rows{r} = [ 'ら', 'り', 'る', 'れ', 'ろ' ];
-    $rows{w} = [ 'わ', 'を', 'ゎ' ];
+    my $chomped = chomp($raw_string);
+    unless ($raw_string) {
+        return "\n" if $chomped;
+        return '';
+    }
 
-    @dullness = (
-        'が', 'ぎ', 'ぐ', 'げ', 'ご', 'ざ', 'じ', 'ず', 'ぜ', 'ぞ',
-        'だ', 'ぢ', 'づ', 'で', 'ど', 'ば', 'び', 'ぶ', 'べ', 'ぼ'
-    );
-    @p_sound = ( 'ぱ', 'ぴ', 'ぷ', 'ぺ', 'ぽ' );
-    @double_consonant =
-      ( 'ぁ', 'ぃ', 'ぅ', 'ぇ', 'ぉ', 'っ', 'ゃ', 'ゅ', 'ょ', 'ゎ' );
+    $raw_string = decode_utf8($raw_string);
+    my $ajifry_word = $self->_to_ajifry($raw_string);
+    $ajifry_word .= "\n" if $chomped;
+    return encode_utf8($ajifry_word);
+}
 
-    my $self = $class->SUPER::new();
-    return $self;
+sub translate_to_ajifry {
+    my ( $self, $raw_string ) = @_;
+    return $self->to_AjiFry($raw_string);
+}
+
+sub to_Japanese {
+    my ( $self, $ajifry_word ) = @_;
+    my $chomped = chomp($ajifry_word);
+
+    unless ($ajifry_word) {
+        return "\n" if $chomped;
+        return '';
+    }
+
+    $ajifry_word = decode_utf8($ajifry_word);
+    my $japanese_word = $self->_to_Japanese($ajifry_word);
+    $japanese_word .= "\n" if $chomped;
+    return encode_utf8($japanese_word);
+}
+
+sub translate_from_ajifry {
+    my ( $self, $ajifry_word ) = @_;
+    return $self->to_Japanese($ajifry_word);
 }
 
 sub _search_key_of_element {
-    my ( $self, $element, %hash ) = @_;
+    my ( $self, $element, $hash ) = @_;
 
-    foreach my $key ( sort keys %hash ) {
-        if ( List::Util::first { $_ eq $element } @{ $hash{$key} } ) {
+    foreach my $key ( sort keys %$hash ) {
+        if ( List::Util::first { $_ eq $element } @{ $hash->{$key} } ) {
             return $key;
         }
     }
 }
 
 sub _find_first {
-    my $self = shift;
-    my ( $key, @list ) = @_;
+    my ( $self, $key, $list ) = @_;
 
-    return ( List::Util::first { $_ eq $key } @list ) ? 1 : 0;
+    return ( List::Util::first { $_ eq $key } @$list ) ? 1 : 0;
 }
 
 sub _find_duplicate_element_in_both_lists {
@@ -98,7 +128,7 @@ sub _find_duplicate_element_in_both_lists {
     my @duplicate_elements;
     foreach my $element_A ( @{$list_A} ) {
         foreach my $element_B ( @{$list_B} ) {
-            if ( $element_A ~~ $element_B ) {
+            if ( $element_A eq $element_B ) {
                 push( @duplicate_elements, $element_A );
             }
         }
@@ -110,18 +140,38 @@ sub _get_ajifry_word_by_consonant {
     my $self      = shift;
     my $consonant = shift;
 
-    given ($consonant) {
-        when ('a') { return "食え" }
-        when ('k') { return "フライ" }
-        when ('s') { return "お刺身" }
-        when ('t') { return "アジ" }
-        when ('n') { return "ドボ" }
-        when ('h') { return "山岡" }
-        when ('m') { return "岡星" }
-        when ('y') { return "ゴク･･･" }
-        when ('r') { return "ああ" }
-        when ('w') { return "雄山" }
-        default    { return "" }
+    if ( $consonant eq 'a' ) {
+        return "食え";
+    }
+    elsif ( $consonant eq 'k' ) {
+        return "フライ";
+    }
+    elsif ( $consonant eq 's' ) {
+        return "お刺身";
+    }
+    elsif ( $consonant eq 't' ) {
+        return "アジ";
+    }
+    elsif ( $consonant eq 'n' ) {
+        return "ドボ";
+    }
+    elsif ( $consonant eq 'h' ) {
+        return "山岡";
+    }
+    elsif ( $consonant eq 'm' ) {
+        return "岡星";
+    }
+    elsif ( $consonant eq 'y' ) {
+        return "ゴク･･･";
+    }
+    elsif ( $consonant eq 'r' ) {
+        return "ああ";
+    }
+    elsif ( $consonant eq 'w' ) {
+        return "雄山";
+    }
+    else {
+        return "";
     }
 }
 
@@ -129,14 +179,26 @@ sub _get_ajifry_word_by_vowel {
     my $self  = shift;
     my $vowel = shift;
 
-    given ($vowel) {
-        when ('a') { return "食え食え" }
-        when ('i') { return "ドボドボ" }
-        when ('u') { return "お刺身" }
-        when ('e') { return "むむ･･･" }
-        when ('o') { return "アジフライ" }
-        when ('n') { return "京極" }
-        default    { return "" }
+    if ( $vowel eq 'a' ) {
+        return "食え食え";
+    }
+    elsif ( $vowel eq 'i' ) {
+        return "ドボドボ";
+    }
+    elsif ( $vowel eq 'u' ) {
+        return "お刺身";
+    }
+    elsif ( $vowel eq 'e' ) {
+        return "むむ･･･";
+    }
+    elsif ( $vowel eq 'o' ) {
+        return "アジフライ";
+    }
+    elsif ( $vowel eq 'n' ) {
+        return "京極";
+    }
+    else {
+        return "";
     }
 }
 
@@ -144,20 +206,41 @@ sub _get_consonant_by_ajifry_word {
     my $self        = shift;
     my $ajifry_word = shift;
 
-    given ($ajifry_word) {
-        when ('食え')       { return 'a' }
-        when ('フライ')     { return 'k' }
-        when ('お刺身')     { return 's' }
-        when ('アジ')       { return 't' }
-        when ('ドボ')       { return 'n' }
-        when ('山岡')       { return 'h' }
-        when ('岡星')       { return 'm' }
-        when ('ゴク・・・') { return 'y' }
-        when ('ゴク･･･')    { return 'y' }
-        when ('ゴク…')      { return 'y' }
-        when ('ああ')       { return 'r' }
-        when ('雄山')       { return 'w' }
-        default             { return }
+    if ( $ajifry_word eq '食え' ) {
+        return 'a';
+    }
+    elsif ( $ajifry_word eq 'フライ' ) {
+        return 'k';
+    }
+    elsif ( $ajifry_word eq 'お刺身' ) {
+        return 's';
+    }
+    elsif ( $ajifry_word eq 'アジ' ) {
+        return 't';
+    }
+    elsif ( $ajifry_word eq 'ドボ' ) {
+        return 'n';
+    }
+    elsif ( $ajifry_word eq '山岡' ) {
+        return 'h';
+    }
+    elsif ( $ajifry_word eq '岡星' ) {
+        return 'm';
+    }
+    elsif ($ajifry_word eq 'ゴク・・・'
+        || $ajifry_word eq 'ゴク･･･'
+        || $ajifry_word eq 'ゴク…' )
+    {
+        return 'y';
+    }
+    elsif ( $ajifry_word eq 'ああ' ) {
+        return 'r';
+    }
+    elsif ( $ajifry_word eq '雄山' ) {
+        return 'w';
+    }
+    else {
+        return;
     }
 }
 
@@ -165,15 +248,26 @@ sub _get_vowel_by_ajifry_word {
     my $self        = shift;
     my $ajifry_word = shift;
 
-    given ($ajifry_word) {
-        when ('食え食え')   { return 'a' }
-        when ('ドボドボ')   { return 'i' }
-        when ('お刺身')     { return 'u' }
-        when ('むむ・・・') { return 'e' }
-        when ('むむ･･･')    { return 'e' }
-        when ('むむ…')      { return 'e' }
-        when ('アジフライ') { return 'o' }
-        default             { return }
+    if ( $ajifry_word eq '食え食え' ) {
+        return 'a';
+    }
+    elsif ( $ajifry_word eq 'ドボドボ' ) {
+        return 'i';
+    }
+    elsif ( $ajifry_word eq 'お刺身' ) {
+        return 'u';
+    }
+    elsif ($ajifry_word eq 'むむ・・・'
+        || $ajifry_word eq 'むむ･･･'
+        || $ajifry_word eq 'むむ…' )
+    {
+        return 'e';
+    }
+    elsif ( $ajifry_word eq 'アジフライ' ) {
+        return 'o';
+    }
+    else {
+        return;
     }
 }
 
@@ -184,8 +278,8 @@ sub _to_ajifry {
     my @raw_chars = split //, $raw_string;
     my $ajifry_word;
     foreach my $raw_char (@raw_chars) {
-        my $vowel     = $self->_search_key_of_element( $raw_char, %cols );
-        my $consonant = $self->_search_key_of_element( $raw_char, %rows );
+        my $vowel     = $self->_search_key_of_element( $raw_char, COLS );
+        my $consonant = $self->_search_key_of_element( $raw_char, ROWS );
 
         if ( !$vowel && !$consonant ) {
             $ajifry_word .= $raw_char;    # not HIRAGANA
@@ -193,16 +287,16 @@ sub _to_ajifry {
         }
 
         $ajifry_word .= "中川"
-          if $self->_find_first( $raw_char, @double_consonant );
+          if $self->_find_first( $raw_char, DOUBLE_CONSONANT );
         $ajifry_word .= $self->_get_ajifry_word_by_consonant($consonant);
         $ajifry_word .= $self->_get_ajifry_word_by_vowel($vowel);
-        $ajifry_word .= "社主" if $self->_find_first( $raw_char, @p_sound );
-        $ajifry_word .= "陶人" if $self->_find_first( $raw_char, @dullness );
+        $ajifry_word .= "社主" if $self->_find_first( $raw_char, P_SOUND );
+        $ajifry_word .= "陶人" if $self->_find_first( $raw_char, DULLNESS );
     }
     return $ajifry_word;
 }
 
-sub _from_ajifry {
+sub _to_Japanese {
     my $self        = shift;
     my $ajifry_word = shift;
 
@@ -222,7 +316,9 @@ sub _from_ajifry {
         }
 
         my $consonant;
-        if ( $ajifry_word =~ s/^(食え|フライ|お刺身|アジ|ドボ|山岡|岡星|ゴク・・・|ゴク･･･|ゴク…|ああ|雄山)// ) {
+        if ( $ajifry_word =~ s/^(食え|フライ|お刺身|アジ|ドボ|山岡|岡星|ゴク・・・|ゴク･･･|ゴク…|ああ|雄山)//
+          )
+        {
             $consonant = $1;
         }
         unless ($consonant) {
@@ -231,7 +327,9 @@ sub _from_ajifry {
             next;
         }
         my $vowel;
-        if ( $ajifry_word =~ s/^(食え食え|ドボドボ|お刺身|むむ・・・|むむ･･･|むむ…|アジフライ)// ) {
+        if ( $ajifry_word =~ s/^(食え食え|ドボドボ|お刺身|むむ・・・|むむ･･･|むむ…|アジフライ)//
+          )
+        {
             $vowel = $1;
         }
         unless ($vowel) {
@@ -250,14 +348,15 @@ sub _from_ajifry {
         $vowel     = $self->_get_vowel_by_ajifry_word($vowel);
 
         my @match_characters =
-          $self->_find_duplicate_element_in_both_lists( $rows{$consonant}, $cols{$vowel} );
+          $self->_find_duplicate_element_in_both_lists( ROWS->{$consonant},
+            COLS->{$vowel} );
         if ($is_p_sound) {
             $translated_word .= $match_characters[2];
         }
         elsif ($is_dullness) {
             $translated_word .= $match_characters[1];
         }
-        elsif ( $is_double_consonant && $consonant ~~ 't' ) {
+        elsif ( $is_double_consonant && $consonant eq 't' ) {
             $translated_word .= $match_characters[2];
         }
         elsif ($is_double_consonant) {
@@ -271,37 +370,6 @@ sub _from_ajifry {
     return $translated_word;
 }
 
-sub translate_to_ajifry {
-    my $self       = shift;
-    my $raw_string = shift;
-    my $chomped    = chomp($raw_string);
-
-    unless ($raw_string) {
-        return "\n" if $chomped;
-        return '';
-    }
-
-    my $ajifry_word = Encode::encode_utf8(
-        $self->_to_ajifry( Encode::decode_utf8($raw_string) ) );
-    $ajifry_word .= "\n" if $chomped;
-    return $ajifry_word;
-}
-
-sub translate_from_ajifry {
-    my $self        = shift;
-    my $ajifry_word = shift;
-    my $chomped     = chomp($ajifry_word);
-
-    unless ($ajifry_word) {
-        return "\n" if $chomped;
-        return '';
-    }
-
-    my $translated_word = Encode::encode_utf8(
-        $self->_from_ajifry( Encode::decode_utf8($ajifry_word) ) );
-    $translated_word .= "\n" if $chomped;
-    return $translated_word;
-}
 1;
 
 __END__
@@ -315,7 +383,7 @@ Acme::AjiFry - AjiFry Language (アジフライ語) Translator
 
 =head1 VERSION
 
-This document describes Acme::AjiFry version 0.08
+This document describes Acme::AjiFry version 0.09
 
 
 =head1 SYNOPSIS
@@ -324,8 +392,8 @@ This document describes Acme::AjiFry version 0.08
 
     my $ajifry = Acme::AjiFry->new();
 
-    print $ajifry->translate_to_ajifry('おさしみ')."\n"; # outputs => "食えアジフライお刺身食え食えお刺身ドボドボ岡星ドボドボ"
-    print $ajifry->translate_from_ajifry('食えアジフライお刺身食え食えお刺身ドボドボ岡星ドボドボ')."\n"; # outputs => "おさしみ"
+    print $ajifry->to_AjiFry('おさしみ')."\n"; # outputs => "食えアジフライお刺身食え食えお刺身ドボドボ岡星ドボドボ"
+    print $ajifry->to_Japanese('食えアジフライお刺身食え食えお刺身ドボドボ岡星ドボドボ')."\n"; # outputs => "おさしみ"
 
 
 =head1 DESCRIPTION
@@ -343,12 +411,12 @@ L<http://ja.uncyclopedia.info/wiki/%E3%82%A2%E3%82%B8%E3%83%95%E3%83%A9%E3%82%A4
 
 new is the constructor of this module.
 
-=item translate_from_ajifry
+=item to_Japanese
 
 This function needs a AjiFry-Language string as parameter.
 It returns Japanese which was translated from AjiFry-Language.
 
-=item translate_to_ajifry
+=item to_AjiFry
 
 This function needs a string as parameter.
 It returns AjiFry-Language which was translated from Japanese.
@@ -357,9 +425,12 @@ It returns AjiFry-Language which was translated from Japanese.
 
 =head1 DEPENDENCIES
 
-Perl 5.10.0 or later.
+=over 4
+
+=item * Encode (version 2.39 or later)
+
+=back
 
-Class::Accessor::Fast 0.34 or later.
 
 =head1 BUGS AND LIMITATIONS
 
